@@ -3,12 +3,12 @@ package Sub::Attribute;
 use 5.008_001;
 use strict;
 
-our $VERSION = '0.06_01';
+our $VERSION = '0.01';
 
 use XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
 
-use parent qw(Exporter);
+use Exporter qw(import);
 our @EXPORT = qw(ATTR_SUB MODIFY_CODE_ATTRIBUTES);
 
 use attributes ();
@@ -22,9 +22,11 @@ Sub::Attribute - Reliable subroutine attribute handlers
 
 =head1 VERSION
 
-This document describes Sub::Attribute version 0.05.
+This document describes Sub::Attribute version 0.01.
 
-=for test_synopsis BEGIN{ $INC{'Attribute/Foo.pm'} = __FILE__ }
+=for test_synopsis
+
+	BEGIN{ $INC{'Attribute/Foo.pm'} = __FILE__ }
 
 =head1 SYNOPSIS
 
@@ -63,7 +65,7 @@ in run-time C<eval()>, so C<ATTR(CODE)> is not reliable.
 
 =head2 The B<ATTR_SUB> meta attribute
 
-Defines a method as an subroutine attribute handler.
+Defines a method as an subrouitne attribute handler.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
@@ -95,7 +97,7 @@ Goro Fuji (gfx) E<lt>gfuji(at)cpan.orgE<gt>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009-20010, Goro Fuji (gfx). Some rights reserved.
+Copyright (c) 2009, Goro Fuji (gfx). Some rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
